# Cloneme
A git clone wrapper to make cloning repos easier

## Getting started
```
pip install cloneme
```

## Usage
```
cloneme <username>/<repository>
```
### Example
```
cloneme LucianoFromTrelew/cloneme
```
